@@ -3,17 +3,17 @@ use crate::{structures::user_structs::*, request::request_rel, Ferinth, Result};
 impl Ferinth {
     /// Get user with ID `user_id`
     pub async fn get_user(&self, user_id: &str) -> Result<User> {
-        Ok(request_rel(self, format!("/user/{}", user_id))
+        request_rel(self, format!("/user/{}", user_id))
             .await?
             .json()
-            .await?)
+            .await
     }
 
     /// List the members of team with ID `team_id`
     pub async fn list_team_members(&self, team_id: &str) -> Result<Vec<TeamMember>> {
-        Ok(request_rel(self, format!("/team/{}/members", team_id))
+        request_rel(self, format!("/team/{}/members", team_id))
             .await?
             .json()
-            .await?)
+            .await
     }
 }
